<a href="https://cognite.com/">
    <img src="https://github.com/cognitedata/correlation/blob/master/img/cognite_logo.png" alt="Cognite logo" title="Cognite" align="right" height="80" />
</a>

Correlation
=======================
[![build](https://webhooks.dev.cognite.ai/build/buildStatus/icon?job=github-builds/correlation/master)](https://jenkins.cognite.ai/job/github-builds/job/correlation/job/master/)
[![codecov](https://codecov.io/gh/cognitedata/correlation/branch/master/graph/badge.svg)](https://codecov.io/gh/cognitedata/correlation)

Correlation analysis tool for contextualization of time series data.

## Documentation
Documentation can be found [here](https://cognite-docs.readthedocs-hosted.com/projects/cognite-cognite-correlation/en/latest/)

## Prerequisites
Python3 (>= 3.5) and pip

## Installation
Use pip for installation:
```bash
$ pip install cognite-correlation
```

## Examples
Some examples can be found in the [documentation](https://cognite-docs.readthedocs-hosted.com/projects/cognite-cognite-correlation/en/latest/),
and some notebooks with examples can be found in the `examples/` directory.

## License
Cognite Packages use the Apache 2.0 License. See [LICENSE](LICENSE)
